@@ -22,9 +22,6 @@
 #ifndef TARGET_ARCH_DEFAULT
 # define TARGET_ARCH_DEFAULT 0
 #endif
-#ifndef TARGET_DEFAULT_CTOR_DTOR
-# define TARGET_DEFAULT_CTOR_DTOR 1
-#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
